@@ -245,12 +245,16 @@ runmodel <- function(
                                        step.max=1.0,
                                        x.tol=1.5e-8,
                                        xf.tol=2.2e-14)
+          # 
+          # optim.control$control<- list(maxfeval=20000L,
+          #                              maxit=10000L,
+          #                              trace=0L)
         }
       }
       
       
       tryres <- try({
-        optim.out <- do.call(optimr,optim.control)
+        optim.out <- do.call(optimr_fake,optim.control)
       }, silent = TRUE)    
 
       if (is(tryres,"try-error") || any(is.na(optim.out$par))){
@@ -259,7 +263,7 @@ runmodel <- function(
         optim.control$par <- parVector(emergencystart(x))
         
         tryres2 <- try({
-          optim.out <- do.call(optimr,optim.control)
+          optim.out <- do.call(optimr_fake,optim.control)
         }, silent = TRUE)    
         
         # If still an error, break:
