@@ -96,6 +96,9 @@ Rcpp::List solve_symmetric_cpp(
     if (logdet){
       double logepsilon = log(epsilon);
       logdetval =  log(det(inv));
+      if (logdetval == R_PosInf){
+        logdetval = real(log_det(inv));
+      }
       if (logdetval < logepsilon){
         logdetval = logepsilon;
       }
@@ -142,8 +145,9 @@ arma::mat solve_symmetric_cpp_matrixonly(
     
   } else {
     // Small spectral shift:
+    // if (lowestEV < sqrt(epsilon)){
     if (lowestEV < sqrt(epsilon)){
-      
+
       for (i=0;i<nvar;i++){
         X(i,i) = X(i,i) - lowestEV + sqrt(epsilon);
       }
