@@ -9,7 +9,6 @@
 using namespace Rcpp;
 using namespace arma;
 
-
 // Asymptotic cov matrix
 // [[Rcpp::export]]
 arma::mat WLS_wmat(
@@ -35,18 +34,33 @@ arma::mat WLS_wmat(
         if (p==0){
           sec(g, h) = 0;
         }
-        sec(g,h) += std::pow((double)ncase,-1.0) * (data(p,g) - means(g)) * (data(p,h) - means(h));
-        for (i = 0; i < nvar; i++){
-          if (p==0){
-            thi(g,h,i) = 0;
-          }
-          thi(g,h,i) += std::pow((double)ncase,-1.0) * (data(p,g) - means(g)) * (data(p,h) - means(h)) * (data(p,i) - means(i)) ;
-          for (j = i; j < nvar; j ++){
+        
+        // Check for NA:
+        if (arma::is_finite(data(p,g)) && arma::is_finite(data(p,h))){
+          sec(g,h) += std::pow((double)ncase,-1.0) * (data(p,g) - means(g)) * (data(p,h) - means(h));
+          for (i = 0; i < nvar; i++){
             if (p==0){
-              four(i,j,g,h) = 0;
+              thi(g,h,i) = 0;
+            }
+            
+            // Check NA:
+            if (arma::is_finite(data(p,i))){
+              thi(g,h,i) += std::pow((double)ncase,-1.0) * (data(p,g) - means(g)) * (data(p,h) - means(h)) * (data(p,i) - means(i)) ;
+              for (j = i; j < nvar; j ++){
+                if (p==0){
+                  four(i,j,g,h) = 0;
+                }
+                
+                // Check NA:
+                if (arma::is_finite(data(p,j))){
+                  four(i,j,g,h) +=  std::pow((double)ncase,-1.0) *(data(p,i) - means(i)) * (data(p,j) - means(j)) * (data(p,g) - means(g)) * (data(p,h) - means(h)); 
+                }
+              }
+              
             }
-            four(i,j,g,h) +=  std::pow((double)ncase,-1.0) *(data(p,i) - means(i)) * (data(p,j) - means(j)) * (data(p,g) - means(g)) * (data(p,h) - means(h));
           }
+        } else {
+          Rf_error("Missing data is not yet supported for WLS without ordered categorical variables");
         }
       }
     }
